Package: miniCRAN
Authors@R: c(person("Microsoft Corporation", role="cph"), person("Andrie", "de
    Vries", role=c("aut", "cre"), email="apdevries@gmail.com"),
    person("Alex", "Chubaty", role="ctb", email="alex.chubaty@gmail.com"))
License: GPL-2
Copyright: Microsoft Corporation
Title: Create a Mini Version of CRAN Containing Only Selected Packages
Description: Makes it possible to create an internally consistent
    repository consisting of selected packages from CRAN-like repositories.
    The user specifies a set of desired packages, and 'miniCRAN' recursively
    reads the dependency tree for these packages, then downloads only this
    subset. The user can then install packages from this repository directly,
    rather than from CRAN.  This is useful in production settings, e.g. server
    behind a firewall, or remote locations with slow (or zero) Internet access.
Date: 2017-10-21
Version: 0.2.10
URL: https://github.com/andrie/miniCRAN
BugReports: https://github.com/andrie/miniCRAN/issues
SystemRequirements: Imports the `curl` and `XML` packages. These have
        system requirements on `libxml2-devel`, `libcurl-devel` and
        `openssl-devel`.
Imports: graphics, httr, magrittr, methods, stats, tools, utils, XML,
        igraph
Suggests: devtools, knitr, rmarkdown, testthat(>= 0.9), covr, withr
LazyData: true
LazyLoad: true
VignetteBuilder: knitr
RoxygenNote: 6.0.1
NeedsCompilation: no
Packaged: 2017-10-22 20:20:04 UTC; adevries
Author: Microsoft Corporation [cph],
  Andrie de Vries [aut, cre],
  Alex Chubaty [ctb]
Maintainer: Andrie de
 Vries <apdevries@gmail.com>
Repository: CRAN
Date/Publication: 2017-10-22 21:25:21 UTC
Built: R 3.3.2; ; 2017-11-15 20:27:50 UTC; windows
